@@ -1,4 +1,7 @@
-var TableRelationshipType = Java.type('schemacrawler.schema.TableRelationshipType');
+/**
+ * Copyright (c) Sualeh Fatehi
+ * SPDX-License-Identifier: EPL-2.0
+ */
 
 var printChildren = function()
 {
@@ -10,7 +13,7 @@ var printChildren = function()
   {
     print('');
     print(table.getFullName());
-    var children = table.getRelatedTables(TableRelationshipType.child);
+    var children = table.getReferencingTables();
     forEach.call(children, function(childTable)
     {
       print("  [child] " + childTable.getFullName());
